package com.dipigraphics.fingersMotion
{
	import flash.events.Event;
	
	/**
	 * This class provides the FingersMotion Event.
	 * 
	 * <p>Created by Denis Pissoort</p>
	 * <p>Produced by <a href="http://www.infographie-sup.be">Haute Ecole Albert Jacquard</a></p>
	 * <p>Email : denis&#64;dipi-graphics.com</p>
	 * <p>HomePage of the project : <a href="http://www.dipi-graphics.com/TFE/project/">Fingers Motion Project HomePage</a></p>
	 * <p>This software is licensed under the <a href="http://creativecommons.org/licenses/GPL/2.0/">CC-GNU GPL</a> version 2.0 or later.</p>
	 * 
	 */ 
	public class FingersMotionEvent extends Event {
		
		/**
		 * FM_ACTIVE This Event is never dispatch but you need to add it to activte the others.  
		 * 
		 */
		public static const FM_ACTIVE:String = "fmActive";
		/**
		 * FM_HOVER represent the Fingers Motion Hover Event  
		 * 
		 */
		public static const FM_HOVER:String = "fmHover";
		/**
		 * FM_OUT represent the Fingers Motion Out Event  
		 * 
		 */
		public static const FM_OUT:String = "fmOut";
		/**
		 * FM_CLICK represent the Fingers Motion Click Event  
		 * 
		 */
		public static const FM_CLICK:String = "fmClick";
		/**
		 * FM_DRAG_AND_DROP represent the Fingers Motion Drag and Drop Event  
		 * 
		 */
		public static const FM_DRAG_AND_DROP:String = "fmDragAndDrop";
		/**
		 * FM_ROTATION represent the Fingers Motion Rotation Event  
		 * 
		 */
		public static const FM_ROTATION:String = "fmRotation";
		
		/**
		 * fmDataTransmitted is used only with the Rotation Event and give you the angle between Yellow and Green in degree.
		 * 
		 */
		public var fmDataTransmitted:*

		/**
		 * This Method provide the Events to interact with your application as a navigation system.
		 * 
		 * <p>This is the list that represent the event you must have to activate the others.</p>
		 * <ul>
		 * <li>FM_ACTIVE<ul><li>FM_HOVER<ul><li>FM_OUT</li><li>FM_CLICK</li><li>FM_DRAG_AND_DROP<ul><li>FM_ROTATION</li></ul></li></ul></li></ul></li>
		 * </ul>
		 * <p>So if there is no FM_HOVER on a Sprite, the FM_CLICK IS NEVER DISPATCH !! Be carefull</p>
		 * 
		 * @example Hover and Rotation Exemple &lt;&lt;How to use event in your application&gt;&gt; :
		 * <listing version="3.0">
		 * //set a container for your application
		 * var MyApplicationContainer:Sprite = new Sprite(); 
		 * [...] // add you application in the container
		 * addChild(MyApplicationContainer);
		 * 
		 * // create the fingers motion navigation
		 * var MyNavigation:fingersMotion = new fingersMotion(MyApplicationContainer,true,true);
		 * addChild(MyNavigation);
		 * 
		 * //Creation of event 
		 * // Assuming that you have a sprite &lt;mySprite&gt; in MyApplicationContainer
		 * 
		 * //Activate Event
		 * // Note : this event is never dispatch.
		 * mySprite.addEventListener(FingersMotionEvent.FM_ACTIVE, activateFingersMotion);
		 * //AddEventListener for hover. If you have no hover Event other Event can't launch.
		 * mySprite.addEventListener(FingersMotionEvent.FM_HOVER, doFingersMotionOver);
		 * 
		 * //create the hover function 
		 * function doFingersMotionOver(e:FingersMotionEvent):void{
		 * trace(e.target); // OUTPUT your Sprite Object.
		 * }
		 * 
		 * //AddEventListener for Drag and Drop. (this event its needed to allow fingersMotion to dispatch the Rotation Events see list above)
		 * mySprite.addEventListener(FingersMotionEvent.FM_DRAG_AND_DROP, doFingersMotionDragAndDrop);
		 * 
		 * //create the Drag and Drop function 
		 * function doFingersMotionDragAndDrop(e:FingersMotionEvent):void{
		 * trace(e.target); // OUTPUT your Sprite Object.
		 * }
		 * 
		 * 
		 * //AddEventListener for rotation.
		 * mySprite.addEventListener(FingersMotionEvent.FM_ROTATION, doFingersMotionRotation);
		 * 
		 * //create the rotation function 
		 * function doFingersMotionRotation(e:FingersMotionEvent):void{
		 * trace(e.target); // OUTPUT your Sprite Object.
		 * trace(e.fmDataTransmitted); // OUTPUT the angle to apply for the rotation
		 * e.target.rotation = e.fmDataTransmitted;
		 * } 
		 * 
		 * </listing>
		 * 
		 * <p>Here is the list that represents the actions sended :</p>
		 * <ul>
		 * <li>yellow = normal mode : hover is dispatch when yellow is on a sprite.</li>
		 * <li>yellow in hover mode + blue = Drag and Drop mode.</li> 
		 * <li>yellow in hover mode  + green = click mode.</li>
		 * <li>Drag an Drop mode + green = rotation mode with drag and drop.</li>
		 * </ul>
		 * 
		 */ 	
		public function FingersMotionEvent(type:String, fmData:*=null, bubbles:Boolean=false, cancelable:Boolean=false)
		{
			super(type, bubbles, cancelable);
			this.fmDataTransmitted = fmData
		}
		/**
		 * not needed
		 * @private
		 */
		public override function clone():Event {
			return new FingersMotionEvent(type,fmDataTransmitted, bubbles, cancelable);
		}
		/**
		 * not needed
		 * @private
		 */
		public override function toString():String {
			return formatToString("FingersMotionEvent", "type","fmDataTransmitted","bubbles", "cancelable", "eventPhase");
		}
	}
}